function [L,U] = fattLU(A)
%
% Fattorizzazione LU .
%
%            A=LU
%
% Parametri di ingresso
%  A    matrice da fattorizzare
%
% Parametri in uscita
% L     matrice triangolare inferiore
% U     matrice triangolare superiore
%
% Autore: Stefano De Marchi
%
[n,m]=size(A);
a=A;


%
% Costruzione matrici L, U con Doolittle
%

for k=1:n,

 
 for i=k:n,
 s1=0;
   for p=1:k-1
    s1=s1+L(k,p)*U(p,i);
   end;
 U(k,i)=a(k,i)-s1;
 end;

 for i=k:n,
 s=0;
  for p=1:k-1
    s=s+L(i,p)*U(p,k);
  end;
 L(i,k)=(a(i,k)-s)/U(k,k);
 end;
end;